@@ -2,7 +2,7 @@ package App::cpm::Job;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.352';
+our $VERSION = '0.900';
 
 sub new {
     my ($class, %option) = @_;
@@ -44,6 +44,16 @@ sub distvname {
     }
 }
 
+sub distname {
+    my $self = shift;
+    $self->{_distname} ||= CPAN::DistnameInfo->new($self->distfile)->dist || 'UNKNOWN';
+}
+
+sub cpanid {
+    my $self = shift;
+    $self->{_cpanid} ||= CPAN::DistnameInfo->new($self->distfile)->cpanid || 'UNKNOWN';
+}
+
 sub type {
     my $self = shift;
     $self->{type};
