@@ -8,7 +8,7 @@ use App::cpm::Logger;
 use Module::Metadata;
 use IO::Handle;
 use version;
-our $VERSION = '0.352';
+our $VERSION = '0.900';
 
 sub new {
     my ($class, %option) = @_;
@@ -20,7 +20,6 @@ sub new {
         _fail_resolve => +{},
         _fail_install => +{},
         _is_installed => +{},
-        _artifacts => +{},
     }, $class;
     if ($self->{target_perl}) {
         require Module::CoreList;
@@ -95,6 +94,7 @@ sub info {
     } else {
         $message = $name;
         $optional = "using cache" if $type eq "fetch" and $job->{using_cache};
+        $optional = "using prebuilt" if $job->{prebuilt};
     }
     my $elapsed = defined $job->{elapsed} ? sprintf "(%.3fsec) ", $job->{elapsed} : "";
 
@@ -195,6 +195,7 @@ sub _calculate_jobs {
                     distfile => $dist->{distfile},
                     uri => $dist->uri,
                     static_builder => $dist->static_builder,
+                    prebuilt => $dist->prebuilt,
                 );
             } elsif (@need_resolve and !$dist->deps_registered) {
                 $dist->deps_registered(1);
@@ -366,11 +367,18 @@ sub _register_fetch_result {
         return;
     }
     my $distribution = $self->distribution($job->distfile);
-    $distribution->fetched(1);
-    $distribution->configure_requirements($job->{configure_requirements});
     $distribution->directory($job->{directory});
     $distribution->meta($job->{meta});
     $distribution->provides($job->{provides});
+
+    if ($job->{prebuilt}) {
+        $distribution->configured(1);
+        $distribution->requirements($job->{requirements});
+        $distribution->prebuilt(1);
+    } else {
+        $distribution->fetched(1);
+        $distribution->configure_requirements($job->{configure_requirements});
+    }
     return 1;
 }
 
@@ -397,7 +405,6 @@ sub _register_install_result {
     my $distribution = $self->distribution($job->distfile);
     $distribution->installed(1);
     $self->{installed_distributions}++;
-    $self->{_artifacts}{$job->distvname} = $job->{directory};
     return 1;
 }
 
